# inmanta
Repository for the inmanta package. This package exists for backwards compatibility and depends on the `inmanta-core` package.
For more information, have a look at [inmanta-core's GitHub page](https://github.com/inmanta/inmanta-core).
